@@ -71,12 +71,13 @@ class BigQuery:
                 # logging.info(traceback.format_exc())
                 flag = False
 
-    def execute_query(self, query, query_config=None, max_retries=0, time_interval=5):
+    def execute_query(self, query, query_config=None, timeout=900, max_retries=0, time_interval=5):
 
         """
         Executes query from from BigQuery table
         :param string query: query for execution
         :param string query_cofig: config for parameterised query
+        :param integer timeout : maximum bigquery execution timeout
         :param string max_retries: maximum retries if data is not fetched
         :param integer time_interval : time interval between retries
         """
@@ -86,7 +87,7 @@ class BigQuery:
         while flag:
             try:
                 query_job = self.bq_client.query(query, job_config=query_config)  # API request
-                query_job.result(timeout=900)  # Waits for statement to finish
+                query_job.result(timeout=timeout)  # Waits for statement to finish
                 logging.debug("------- Query Executed successfully ----- ")
                 flag = False
             except requests.exceptions.Timeout:
