@@ -2,6 +2,7 @@ import os
 import json
 import boto3
 import logging
+from trell.exceptions import AwsConnectionError
 
 # from trell.utils import LogFormatter
 # LogFormatter.apply()
@@ -32,4 +33,5 @@ try:
     
 except Exception as err:
     print("** --- you are not authorized to use Trell pip package --- **")
-    print("Follow one of the folling steps to use Trell pip package \n 1. Attach ds-general-ec2 IAM role to the machine  \n 2. Setup AWS CLI \n 3. manually set up the credentials via \n    from trell_ai_util.utils import Credential \n    Credential.set(ACCESS_KEY='*****', SECRET_KEY='*****') ")
\ No newline at end of file
+    print("Follow one of the folling steps to use Trell pip package \n 1. Attach ds-general-ec2 IAM role to the machine  \n 2. Setup AWS CLI \n 3. manually set up the credentials via \n    from trell_ai_util.utils import Credential \n    Credential.set(ACCESS_KEY='*****', SECRET_KEY='*****') ")
+    print(err)
\ No newline at end of file
